<H2>NAME</H2>

<P><B>%name</B> - %description</P>


<H2>SYNOPSIS</H2>

<PRE>
<B>%name</B> <B>-t</B> <I>data-tstep</I>[,<I>norm-tstep</I>[,<I>med-tstep</I>[,<I>sm-tstep</I>]]]
      [ <B>-r</B> <I>restart-index </I> ] [ <B>-n</B> <I>#steps </I> ]
      [ <B>-I</B> <I>init-image </I> ] [ <B>-i</B> <I>input-prefix </I> ] [ <B>-p</B> <I>prfile </I> ]
      [ <B>-m</B> <I>mask </I> ] [ <B>-O</B> <I>output-frequency </I> ] [ <B>-d</B> <I>max-active </I> ]
      [ <B>-e</B> <I>em_prefix </I> ] [ <B>-s</B> <I>snow_prefix </I> ] [ <B>-P</B> <I>nthreads </I>] 
      [ <B>-h</B> ] [ <B>-U</B> ] [ <B>-K</B> ] [ <B>-v</B> ] [ <B>-b</B> <I>nbits </I> ]
      [ <B>-M</B> <I>max-h2o </I> ] [ <B>-C</B> [<I>compress_cmd</I>] ]
      [ <B>-T</B> <I>norm-threshold</I>[,<I>med-threshold</I>[,<I>sm-threshold</I>]]<I> </I> ] 
</PRE>

<H2>DESCRIPTION</H2>

<P>
DEM grid-based model using the energy balance to calculate
snowmelt, and to predict runoff, from input data on snow
properties, terrain and region characteristics, precipitation,
and climate.  Similar to the approach used by Anderson
(1976), and Morris (1982), but designed to run on simpler,
more generalizable inputs.  The model was first presented by
Marks (1988), described conceptually by Marks, et. al (1992)
and Marks and Dozier (1992), and then described in great
detail by Marks, et. al (1997).
<P>
The model approximates the snow cover as being composed of
two layers, a surface fixed-thickness active layer and a
lower layer, solving for the temperature (C) and specific
mass (kg/m^2) which is the mass per unit area (from density
* depth (kg/m^3 * m)) for each layer, and then computing the
temperature and specific mass for the snowcover.
<P>
Melt is computed in either layer when the accumulated energy
exceeds the &quot;cold content&quot; or when the &quot;cold content&quot; is &gt;
0.0.  Cold content is the energy required to bring the snow
cover temperature up to freezing (0 C).  Runoff is estimated
when the accumulated melt and liquid H2O content exceeds a
user-defined threshold.
<P>
This version of the model is a simplification of the point
version, snobal, designed to run over a DEM grid or image of
10^4 to 10^6 cells.  It has been successfully tested over
the Emerald Lake basin in the Sierra Nevada (5m DEM, 5x10^4
grid cells), the Boise River basin in Idaho (250m DEM,
3.5x10^4 grid cells), and the Park City drainage in the
Wasatch Mts. of Utah (75m DEM, 8.2x10^4 grid cells) on runs
of 2 weeks to 6 months.  The only constraint on the size of
the grid is available disk storage, memory, and CPU speed.
(A 6 month run over the Park City grid required 500Mb of
input files, generated 1500Mb of output, and took 6.5 hours
on a SUN Ultra 170E with 256Mb of real memory.)
<P>
Constants, assumed over the grid:
</P><PRE>
     max_z_s_0   = 0.25 m   Thickness of the active layer
     z_u         = 5.0 m    Height above the ground of the
                              wind speed measurement
     z_T         = 5.0 m    Height above the ground of the
                              air temperature and vapor
                              pressure measurements
     z_g         = 0.5 m    Depth below the ground surface
                              of the soil temperature
                              measurement
</PRE><P>
Inputs:
<P>
Input image data are required for initial snowcover and surface
conditions, for input climate data at each time-step,
and for precipitation events.  Initial condition data are
specified only at the beginning of the run.  Precipitation
data include an ASCII file specifying the time since the run
start for the event and the name of the precipitation file,
which contains precipitation mass, % snow, snow density, and
precipitation temperature.
<P>
Initial conditions image (7-band):
</P><PRE>
     z         =   elevation (m)
     z_0       =   roughness length (m)
     z_s       =   total snowcover depth (m)
     rho       =   average snowcover density (kg/m^3)
     T_s_0     =   active snow layer temperature (C)
     T_s       =   average snowcover temperature (C)
     h2o_sat   =   % of liquid H2O saturation (relative
                   water content, i.e., ratio of water in
                   snowcover to water that snowcover could
                   hold at saturation)
</PRE><P>
If the <B>-r</b> option (restart), the image has an additional band
for the lower snow layer's temperature, T_s_l, (8-bands):
</P><PRE>
     z         =   elevation (m)
     z_0       =   roughness length (m)
     z_s       =   total snowcover depth (m)
     rho       =   average snowcover density (kg/m^3)
     T_s_0     =   active snow layer temperature (C)
     T_s_l     =   temperature of the snowpack's lower
                   layer (C)
     T_s       =   average snowcover temperature (C)
     h2o_sat   =   % of liquid H2O saturation (relative
                   water content, i.e., ratio of water in
                   snowcover to water that snowcover could
                   hold at saturation)
</PRE><P>
Precipitation data is defined by an ASCII description file
that includes one line per precipitation event, where each
line has the format:
</P><PRE>
   time_since_run_start (decimal hrs.)   name_of_precip_image
</PRE><P>
where the first entry must be &gt;= start time.
<P>
Precipitation image (4-band):
</P><PRE>
     m_pp       =   total precipitation mass (kg/m^2)
     %_snow     =   % of precipitation mass that was snow (0 to 1.0)
     rho_snow   =   density of snowfall (kg/m^3)
     T_pp       =   average precip. temperature (C) (from dew point
                    temperature if available, or can be estimated
                    from air temperature during storm, or minimum
                    daily temperature)
</PRE><P>
Like the point model, the DEM-based model will parse mixed
rain/snow events.  It is designed to accept inputs that
could be derived from typical NRCS Snotel data such as total
precipitation, snow mass increase, and temperature.  The
user must estimate average density and percent snow if depth
data are unavailable.  The model makes the following assumptions
about the snow temperature, rain temperature, and
liquid water saturation of the snow:
</P><PRE>
     when 0.0 &lt; %_snow &lt; 1.0, (a mixed rain/snow event)
          snow temperature = 0.0
          rain temperature = T_pp
          liquid H2O sat.  = 100%
</PRE><PRE>
     when %_snow = 1.0 and T_pp =&gt; 0.0, (a warm snow-only event)
          snow temperature = 0.0
          liquid H2O sat.  = 100%
</PRE><PRE>
     when %_snow = 1.0 and T_pp &lt; 0.0, (a cold snow event)
          snow temperature = T_pp
          liquid H2O sat.  = 0%
</PRE><P>
Input images with climate parameters are required for each
time-step to drive the model.  These 5- or 6-band images
must have a common prefix, and a suffix that indicates the
relative order of the inputs numerically (e.g.,
&quot;input_prefix.N&quot;, where &quot;N&quot; is the time-step index).  The
first value of &quot;N&quot; should always be zero (0), and the last
should always be (1 - #_inputs).  &quot;N&quot; should be padded with
zeros so that every value of &quot;N&quot; has the same number of
digits as the last value of &quot;N&quot;.  For example, if there are
1200 input files, then &quot;N&quot; will always have 4 digits (e.g.,
input_prefix.0000, input_prefix.0001, ...,
input_prefix.1199).
<P>
Input image (6-band):
</P><PRE>
     I_lw   =   incoming thermal (long-wave) radiation (W/m^2)
     T_a    =   air temperature (C)
     e_a    =   vapor pressure (Pa)
     u      =   wind speed (m/sec)
     T_g    =   soil temperature at 0.5 m depth (C)
     S_n    =   net solar radiation (W/m^2)
</PRE><P>
If there is no solar radiation (the sun is &quot;down&quot;), the last
band may be omitted.
<P>
Time-steps (data time-step and run time-steps):
<P>
The &quot;data time-step&quot; is the time interval, in minutes,
between the input images.  The model assumes that this
interval is constant.  Because the snowcover energy balance
is very sensitive to diurnal variations in climate (radiation,
temperature, etc.), the &quot;data time-step&quot; must be 360
minutes (6 hours) or less.  Best results are achieved with a
data time-step of 180 minutes (3 hours) or less.  Data
time-steps greater than 60 minutes must be multiples of
whole hours (e.g., 120 minutes, or 180 minutes).
<P>
A &quot;run time-step&quot; is the internal time-step that the model
actually solves the energy balance over.  Because input
values are assumed to be averages over a run time-step, it
is always 60 minutes (1 hour) or less to insure a stable
model solution.  Solution instabilities occur when the run
time-step is too long to account for rapid changes in the
energy balance (e.g., at sun rise or sunset), or when a
layer's mass is too small to accommodate the assumption of
an average flux over the run time-step.
<P>
There are 3 lengths of run time-steps: &quot;normal, medium, and
small&quot;.  By default, the model uses the normal run time-step
which is the longest of the three run time-steps.  The normal
time-step must divide evenly into the data time-step
(i.e., the data time-step is an integer multiple of the normal
run time-step).  The input data for a normal run time-
step (climate data and some precipitation values) are computed
from the input records by linear interpolation.
<P>
The shorter run time-steps (medium and small) are to insure
solution stability, and are only used as a layer's mass
diminishes to the user defined threshold.  When either
layer's mass drops below the specified threshold, the model
divides a larger run time-step into shorter run time-steps
(e.g., divides a normal run time-step into medium run time-steps).
There are three mass thresholds; one for each run
time-step: normal, medium, and small.  When a layer's mass
falls below the threshold for the the small run time-step,
the model removes the layer.
<P>
Just as the normal run time-step divides evenly into the
data time-step, each of the two shorter run time-steps must
divide evenly into the next larger run time-step (medium
into normal, small into medium).  And like the normal time-
steps, the input data for medium and small time-steps are
linearly interpolated from the input records.
<P>
Because the mass thresholds will be reached at different
times over the DEM grid, the model solution of the energy
balance at a given time-step may require different run
time-steps over the grid.  This improves model efficiency,
requiring additional iterations only for those grid cells
where the mass is below a critical threshold.
<P>
Outputs:
<P>
The model writes a pair of output images at the end of the
model run, unless the output frequency option (<B>-O</b>) is specified.
Output images are a 10-band energy and mass flux
image, and a 9-band snow condition image.  If the &quot;<B>-O</b>&quot;
option is specified, a pair of output images can be generated
at a frequency up to one per input image.  Typically,
however, output is generated at a lower frequency than
input.  For example if input data time-step is 3 hrs (180
min), and a daily output is required, then the output frequency
is set at &quot;8&quot; (1 pair of output images for every 8
input images).
<P>
Energy &amp; mass flux image (10-band):
</P><PRE>
     R_n          =   average net all-wave rad (W/m^2)
     H            =   average sensible heat transfer (W/m^2)
     L_v_E        =   average latent heat exchange (W/m^2)
     G            =   average snow/soil heat exchange (W/m^2)
     M            =   average advected heat from precip. (W/m^2)
     delta_Q      =   average sum of e.b. terms for snowcover (W/m^2)
     E_s          =   total evaporation (kg, or mm/m^2)
     melt         =   total melt (kg, or mm/m^2)
     ro_predict   =   total predicted runoff (kg, or mm/m^2)
     cc_s         =   snowcover cold content (energy required to
                      bring snowpack's temperature to 273.16K)
                      (J/m^2)
</PRE><P>
Note:  The averages are mean values since the last energy &amp;
mass output image; totals are since the last energy &amp; mass
output image; If the &quot;<B>-O</b>&quot; option is not set, averages and
totals are for the entire run.
<P>
Snow conditions image (9-band):
</P><PRE>
     z_s       =   predicted depth of snowcover (m)
     rho       =   predicted average snow density (kg/m^3)
     m_s       =   predicted specific mass of snowcover (kg/m^2)
     h2o       =   predicted liquid H2O in snowcover (kg/m^2)
     T_s_0     =   predicted temperature of surface layer (C)
     T_s_l     =   predicted temperature of lower layer (C)
     T_s       =   predicted average temp of snowcover (C)
     z_s_l     =   predicted lower layer depth (m)
     h2o_sat   =   predicted % liquid h2o saturation
</PRE>
<H2>OPTIONS</H2>


<DL>
<DT><B>-t</B> <I>data-tstep</I>[,<I>norm-tstep</I>[,<I>med-tstep</I>[,<I>sm-tstep</I>]]]
<DD>
data-tstep is time step for the input images (minutes).
If more than 60 minutes (1 hour), than it must a multiple
of 60 minutes, e.g., 120 minutes (2 hrs), 180 min
(3 hrs), etc.  Maximum is 360 minutes (6 hours).
</DD>

<P>norm-tstep is the normal run time-step.  It must divide
the data time-step evenly (default: 60 min or the data
time-step, whichever is smaller).
</P>

<P>med-tstep is the medium run time-step.  It must divide
the normal run time-step evenly (default: 15 min or the
normal time-step, whichever is smaller).
</P>

<P>sm-tstep is the small run time-step.  It must divide
the medium run time-step evenly (default: 1 min).
</P>

<P>
<DT><B>-T</B> <I>norm-threshold</I>[,<I>med-threshold</I>[,<I>sm-threshold</I>]]<I> </I>
<DD>
If a layers mass is below norm-threshold, the model
divides each normal run time-step into medium run
time-steps (default 60 kg/m^2).
</DD>

<P>If a layers mass is below med-threshold, the model
divides each medium run time-step into small run time-
steps (default 10 kg/m^2).
</P>

<P>If a layers mass is below sm-threshold, the model considers
the layer non-existent, i.e., it removes the
layer (default 1 kg/m^2).
</P>

<P>
<DT><B>-r</B> <I>restart-index </I>
<DD>
The model is being restarted with restart_index as the
step index of the first time-step.  This index must be
&gt; 0 (default: the index of the first time-step is 0).
</DD>

<P>
<DT><B>-n</B> <I>#steps </I>
<DD>
Number of time steps for the model to run (default: 1).
</DD>

<P>
<DT><B>-d</B> <I>max-active</I>
<DD>
<I>max-active</I> is maximum depth for active snow layer (m)
(default: 0.25 m).
</DD>

<P>
<DT><B>-I</B> <I>init-image </I>
<DD>
Initial conditions image.  If the <B>-r</b> option is not
present, this image has 7 bands.  If the <B>-r</b> option is
present, the image has additional 8th band which specifies
the temperature of the snowpack's lower layer.
</DD>

<P>
<DT><B>-i</B> <I>input-prefix </I>
<DD>
Input image prefix; each input image has 5 or 6 bands;
if the sun is down, the sixth band is omitted.
</DD>

<P>
<DT><B>-p</B> <I>prfile </I>
<DD>
The ASCII text precipitation input definition file
defining the event time and the name of the 4-band
precipitation image.
</DD>

<P>
<DT><B>-m</B> <I>mask </I>
<DD>
Mask image defining the grid cells over which the model
will be run.
</DD>

<P>
<DT><B>-O</B> <I>output-frequency </I>
<DD>
The frequency at which output images are generated
relative to the frequency of inputs.  (default: two
output images (1 energy/mass and 1 snow properties) at
the end of the run).
</DD>

<P>
<DT><B>-e</B> <I>em_prefix </I>
<DD>
The 10-band energy/mass output images are called
&quot;em_prefix.N&quot; where N is N is the index of the current
time-step.  N is padded with zeroes like the suffixes
for the input images (see <B>-i</b> option).
</DD>

<P>
<DT><B>-s</B> <I>snow_prefix </I>
<DD>
snow_prefix
The 9-band snow-conditions output images are called
&quot;snow_prefix.N&quot; where N is N is the index of the
current time-step.  N is padded with zeroes like the
suffixes for the input images (see <B>-i</b> option).
</DD>

<P>
<DT><B>-P</B> <I>nthreads </I>
<DD>
number of threads to use, Default = 1 (parallel processing)
</DD>

<P>
<DT><B>-h</B> 
<DD>
If set, relative heights will be FALSE and measurement heights will
be relative to the ground.  Defaults to TRUE and measurement
heights will be relative to the snow surface.
</DD>


<P>
<DT><B>-U</B> 
<DD>
The units field of each input images LQ headers are
checked to make sure the proper units are being used.
A units mismatch causes a warning to be issued.
(Default: no units checking).
</DD>

<P>
<DT><B>-M</B> <I>max-h2o </I>
<DD>
The snowcover's maximum liquid H2O content as a volume
ratio: V_water/(V_snow - V_ice); used to predict runoff
(default: 0.01).
</DD>

<P>
<DT><B>-C</B> [ <I>compress_cmd</I> ]
<DD>
Forces compression of output images; compress_cmd can
be specified to force use of a specific compression
command.  If compress_cmd is not specified, then the
model uses &quot;gzip&quot; (default: output images are not
compressed).
</DD>

<P>
<DT><B>-v</B> 
<DD>
Verbose output to the command prompt, default none
</DD>

<P>
<DT><B>-b</B> <I>nbits </I>
<DD>
Number of bits for output image (default: 8).
</DD>

</DL>

<H2>OPERANDS</H2>

<P>
None.
</P>

<H2>EXAMPLES</H2>



<H2>FILES</H2>

<P>None.

<H2>DIAGNOSTICS</H2>



<H2>RESTRICTIONS</H2>

<P>
None.
</P>

<H2>HISTORY</H2>

<DL>

<DT>Sep 1990</DT>
<DD>Modified D. Marks point model (QDIPS program
snobal) to run over IPW image, by Kelly Longley,
Oregon State University, Environmental Research Laboratory, Corvallis
</DD>

<P>

<DT>Sep 1990</DT>
<DD>Now loops on time steps (with temp file) and
handles precip, by K. Longley, OSU, EPA ERL-C
</DD>

<P>

<DT>Oct 1990</DT>
<DD>Added intermediate outputs and restart mode - All works!
by K. Longley, OSU, EPA ERL-C
</DD>

<P>

<DT>Nov 1990</DT>
<DD>Output image contains averages and/or totals;
restart image now needs 24 bands, by K. Longley OSU, EPA ERL-C
</DD>

<P>

<DT>Nov 1990</DT>
<DD>Sped up by making temp file have variable
length lines (no data for masked points), by K. Longley, OSU, EPA ERL-C
</DD>

<P>

<DT>Dec 1990</DT>
<DD>Averages outputs since last output instead
over entire run, by K. Longley, OSU, EPA ERL-C
</DD>

<P>

<DT>Jul 1996</DT>
<DD>Modified program structure to use library of routines shared with
'snobal' program.  Renamed options for consistency with 'snobal'.
Added <B>-U</b> and <B>-M</b> options.  J. Domingo, OSU.
</DD>

<P>

<DT>Jan 1997</DT>
<DD>The suffixes for the input images now have a fixed number of digits
(e.g., snow.001, snow.002, ..., snow.010 instead of snow.1,
snow.2, ..., snow.10) J. Domingo, OSU
</DD>

<P>

<DT>Apr 1997</DT>
<DD>Updated snobal library to limit snow density to 750 kg/m^3.
Minor corrections to this man page.  Fixed bug so that h2o_sat is written
into the temporary image between timesteps.  Snow temperatures where
there's no snow are set to a minimum snow temperature (-75 C)
instead of 0 K (= -273.16) to yield smaller quantization ranges in
snow output images.  J. Domingo, OSU
</DD>

<P>

<DT>May 1997</DT>
<DD>Updated snobal library: when snowcover's mass falls below the
small timestep's threshold, it now becomes runoff (instead of being
tossed away); and, fixed bug so that turbulent transfer calculations
use difference between snowcover height and measurement heights.
Isnobal now checks to make sure prefixes for both types of output
images are different (<B>-e</b> and <B>-s</b> options).  J. Domingo, OSU
</DD>

<DT>July 2015</DT>
<DD>Created option to change surface layer thickness (<B>-d</B> option).  Scott Havens, ARS
</DD>

<DT>November 2015</DT>
<DD>iSnobal multi processor (<B>-P</B> option) and can change relative heights of measurements (<B>-h</B> option) Scott Havens, ARS
</DD>

</DL>

<H2>BUGS</H2>

<P>
None.
</P>

<H2>SEE ALSO</H2>

<DL>
<DT>IPW:</DT>
<DD>
<A HREF="advec.html">advec</A>,
<A HREF="albedo.html">albedo</A>,
<A HREF="elevrad.html">elevrad</A>,
<A HREF="glob.alb.html">glob.alb</A>,
<A HREF="gsnow.html">gsnow</A>,
<A HREF="gradient.html">gradient</A>,
<A HREF="horizon.html">horizon</A>,
<A HREF="refdx.html">refdx</A>,
<A HREF="shade.html">shade</A>,
<A HREF="stoporad.html">stoporad</A>,
<A HREF="solar.html">solar</A>,
<A HREF="selevrad.html">selevrad</A>,
<A HREF="sunlight.html">sunlight</A>,
<A HREF="thermin.html">thermin</A>,
<A HREF="tcloud.html">tcloud</A>,
<A HREF="toporad.html">toporad</A>,
<A HREF="toporad.24.html">toporad.24</A>,
<A HREF="topquad.html">topquad</A>,
<A HREF="topotherm.html">topotherm</A>,
<A HREF="trad.html">trad</A>,
<A HREF="viewf.html">viewf</A>,
<A HREF="topotherm.html">topotherm</A>,
<A HREF="mkprecip.html">mkprecip</A>,
<A HREF="snobal.html">snobal</A>,
<A HREF="snowmass.html">snowmass</A>,
<A HREF="swe.html">swe</A>,
<A HREF="wbal.html">wbal</A>,
<A HREF="dewpt.html">dewpt</A>,
<A HREF="deltaT.html">deltaT</A>,
<A HREF="deltaz.html">deltaz</A>,
<A HREF="pott.html">pott</A>,
<A HREF="rh2vp.html">rh2vp</A>,
<A HREF="satvp.html">satvp</A>,
<A HREF="sling.html">sling</A>,
<A HREF="surface.html">surface</A>,
<A HREF="surftmp.html">surftmp</A>,
<A HREF="vptr.html">vptr</A>,
<A HREF="zpr.html">zpr</A>
</DD>
</DL>

<P>
<A HREF="../bib.html#Anderson 1976">Anderson 1976</A>,
<A HREF="../bib.html#Morris 1982">Morris 1982</A>,
<A HREF="../bib.html#Marks 1988">Marks 1988</A>,
<A HREF="../bib.html#Marks 1992a">Marks 1992a</A>,
<A HREF="../bib.html#Marks 1992b">Marks 1992b</A>,
<A HREF="../bib.html#Garen 1996">Garen 1996</A>,
<A HREF="../bib.html#Van Heeswijk 1996">Van Heeswijk 1996</A>,
<A HREF="../bib.html#Marks 1998">Marks 1998</A>,
<A HREF="../bib.html#Marks 1999a">Marks 1999a</A>,
<A HREF="../bib.html#Susong 1999">Susong 1999</A>
</P>

