<H2>NAME</H2>

<P><B>%name</B> - %description</P>


<H2>SYNOPSIS</H2>

<PRE>
<B>%name</B> <B>-d</B> <I>i</I>,<I>i</I>,<I>i</I> <B>-o</B> <I>out_prefix</I> [ <B>-m</B> <I>mask</I> ] [ <B>-q</B> <I>npts</I> ]
      [ <B>-b</B> <I>#bits</I>[,<I>..</I>] ] [<I>geoh</I>]
</PRE>

<H2>DESCRIPTION</H2>

<P>
<B>%name</B> is part of a family of large area, or &quot;global&quot;,
scale radiation transfer simulation, and solar/terrain geometry calculation
tools, developed after the small-scale radiation transfer and terrain
structure tools, developed at UCSB by Jeff Dozier, Jim Frew,
and Ralph Dubayah.
</P><P>
All of the global-scale radiation transfer tools, except <B>%name</B>,
are designated by the &quot;g&quot; prefix in front of the small-scale tool's
name.  These tools assume that solar geometry, atmospheric properties,
and sun rise and sun set vary over the grid, and they also correct for
earth curvature when computing horizons, terrain and sky view factors,
and illumantion angles.
</P><P>
These global-scale radiation and terrain processing tools can be applied
to areas of size, up to the entire earth.  The global-scale radiation
and terrain processing tools were originally developed by Kelly Longley,
Oregon State University, at the Corvallis, Oregon, EPA lab, in the early
1990's.
</P><P>
<B>%name</B> is basically the global-scale version of the program
sunlight, and should probably be called &quot;gsunlight&quot;, but the program gsunlight does
not calculate quadrature weights, because usually integration over large
geographic areas is too time-consuming (in CPU time) to be done.
</P><P>
<B>%name</B> calculates Kronrod weights and sun angles for numerical
integration of solar radiation over a global-scale image for one day,
currently with either 15 or 21 Kronrod quadrature points.
The input geoh (or image with geoh) must be in lat/lon projection.
<B>%name</B> creates &lt;npts&gt; output images (one for each Kronrod
weight) each with three bands: the Kronrod quadrature weighting factor,
mu (cos zenith angle), followed by the azimuth (degrees).  The
output images are called &lt;out_prefix&gt;.0, ... ,&lt;out_prefix&gt;.&lt;npts-1&gt;.
</P>
<H2>OPTIONS</H2>


<DL>
<DT><B>-d</B> <I>i</I>,<I>i</I>,<I>i</I>
<DD>
date (year, month, day)

<P>
<DT><B>-o</B> <I>out_prefix</I>
<DD>
prefix for output image names

<P>
<DT><B>-m</B> <I>mask</I>
<DD>
mask image

<P>
<DT><B>-q</B> <I>npts</I>
<DD>
# quadrature points (default: 15)

<P>
<DT><B>-b</B> <I>#bits</I>[,<I>..</I>]
<DD>
# bits in output image (1 or 3 values - one number for
all bands or a number for each band)
</DD>
</DL>

<H2>OPERANDS</H2>

<DL>
<DT>[<I>geoh</I>]</DT>

<DD>	geoh	input geoh containing latitude/longitude projection:
		latitudes are in decimal degrees from -90.0 (S.pole) to 90.0 (N)
		longitudes are in continuous degrees from -180.0 - 180.0 (+E/-W)
		(defaults to stdin)
</DD><P>
</P>
</DL>

<H2>EXAMPLES</H2>

<P>
To calculate quadrature weights over a 30s dem grid of the US, for
February 15, 1995, given the geoh geoh.us.30s:
</P><PRE>
	gsunweights -d 1995,02,15 -o us.02.15 -m mask.geo.us geoh.us.30s
</PRE>
<H2>FILES</H2>

<PRE>
     None
</PRE>

<H2>DIAGNOSTICS</H2>

<DL>

<P>
<DT>None
</DT>
</DL>

<H2>RESTRICTIONS</H2>

<P>
None
</P>
<H2>HISTORY</H2>


<DL>
<DT>Jul 1990</DT>
<DD>
Written by Kelly Longley, Oregon State University,
Environmental Research Laboratory, Corvallis OR
</DD>
</DL>

<DL>
<DT>Jan 1991</DT>
<DD>
Changed to run from GEO header rather than file of
lat/lon points, by K. Longley, OSU, EPA ERL-C
</DD>
</DL>

<DL>
<DT>May 1991</DT>
<DD>
Added -n nbits option, K. Longley, OSU, EPA, ERL-C
</DD>
</DL>

<DL>

<DT>Jul 1991</DT>
<DD>
Faster version, no longer computes sunrise &amp; set for
each pixel Writes one image at a time; quantizes output
images separately for maximum accuracy,
by K. Longley, OSU, EPA ERL-C
</DD>

</DL>
<DL>

<DT>Oct 1997</DT>
<DD>
Renamed program from sunweights to <B>%name</B>.  J. Domingo, OSU
</DD>

</DL>

<H2>BUGS</H2>

<P>
None.
</P>
<H2>SEE ALSO</H2>


<DL>
<DT>IPW</DT>
<DD>	<B><A href="elevrad.html">elevrad</A></B>,
<B><A href="gelevrad.html">gelevrad</A></B>,
<B><A href="gsunlight.html">gsunlight</A></B>,
<B><A href="gtoporad.html">gtoporad</A></B>,
<B><A href="gtoporad.24.html">gtoporad.24</A></B>,
<B><A href="gtopquad.html">gtopquad</A></B>,
	<B><A href="toporad.html">toporad</A></B>,
<B><A href="selevrad.html">selevrad</A></B>,
<B><A href="solar.html">solar</A></B>,
<B><A href="stoporad.html">stoporad</A></B>,
<B><A href="sunlight.html">sunlight</A></B>,
<B><A href="toporad.html">toporad</A></B>,
<B><A href="topquad.html">topquad</A></B>
</DD>
</DL>
<P>Marks, D., and J. Dozier, 1979.  &quot;A clear-sky longwave radiation model
	for remote alpine areas&quot;, Archiv fur Meteorologie, Geophysik
	und Bioklimatologie, Series B, vol. 27, no. 23, pp. 159-187.
</P>
<P>Dozier, J., 1980.  &quot;A clear-sky spectral solar radiation model for
	snow-covered mountainous terrain&quot;.  Water Resources Research,
	vol. 16, pp. 709-718.
</P>
<P>Dozier, J., and J. Frew, 1981.  &quot;Atmospheric corrections to satellite
	radiometric data over rugged terrain&quot;.  Remote Sensing of
	Environment, vol. 11, pp. 191-205.
</P>
<P>Dozier, J., J. Bruno, and P. Downey, 1991.  &quot;A faster solution to the
	horizon problem&quot;, Computers and Geosciences, volume 7,
	number 2, pp. 145-151.
</P>
<P>Dozier, J., and J. Frew, 1990.  Rapid calculation of terrain parameters
	for radiation modeling from digital elevation data&quot;. IEEE
	Transactions on Geoscience and Remote Sensing, vol. 28, no. 5,
	pp. 963-969.
</P>
<P>Dubayah, R., J. Dozier, and F. Davis, 1990.  &quot;Topographic distribution
	of clear-sky radiation over the Konza Prairie, Kansas&quot;.  Water
	Resources Research, vol. 26, no. 4, pp. 679-691.
</P>
<P>Marks, D., R. Dubayah, and K. Longley, 1991.  &quot;Modeling the topographic
	and spectral variability of clear-sky solar radiation at regional
	to continental scales.  Proceedings 1991 IGARSS Symposium,
	Remote Sensing:  Global Monitoring for Earth Management, Espoo,
	Finland, Vol. 3, pp. 1711.
</P>
<P>Dubayah, R., and V. Van Katwijk, 1992.  &quot;The topographic distribution
	of annual incoming solar radiation in the Rio Grande basin&quot;.
	Geophysical Research Letters, vol. 19, pp. 2231-2234.
</P>
<P>Dubayah, R., 1994.  &quot;Modeling a solar radiation topoclimatology for the
	Rio Grande River Basin&quot;.  Journal of Vegetation Science, vol. 5,
	pp. 627-640.
</P>

