<H2>NAME</H2>

<P><B>%name</B> - %description</P>


<H2>SYNOPSIS</H2>

<PRE>
<B>%name</B> [ <B>-n</B> ] [ <B>-b</B> <I>#bits</I> ] [<I>image</I>]
</PRE>

<H2>DESCRIPTION</H2>

<P>
Gtoporad is part of a family of large area, or &quot;global&quot;, scale radiation
transfer simulation, and solar/terrain geometry calculation tools,
designed from the small-scale radiation transfer and terrain structure
tools, developed at UCSB by Jeff Dozier, Jim Frew, and Ralph Dubayah.
</P><P>
All of the global-scale radiation transfer and terrain processing tools
are designated by the &quot;g&quot; prefix in front of the small-scale tool's name.
These tools assume that solar geometry, atmospheric properties, and sun
rise and sun set vary over the grid.  They also correct for earth
curvature when computing horizons, terrain and sky view factors,
and illumantion angles.
</P><P>
These global-scale radiation and terrain processing tools can be applied
to areas of any size, up to the entire earth.  They were originally
developed by Kelly Longley, Oregon State University, at the Corvallis,
Oregon, EPA lab, in the early 1990's.
</P><P>
Gtoporad is the global-scale version of the program toporad.
Gtoporad calculates the topographic distribution of solar
radiation at a single time, using input beam and diffuse
radiation calculations supplied by gelevrad.
The input image contains 8 bands in the following order:
</P><PRE>
	cos solar zenith angle		(from gsunlight)
	beam irradiance			(from gelevrad)
	diffuse irradiance		(from gelevrad)
	cos local illumination angle	(from gshade)
	sky view factor			(from gviewf)
	terrain configuration factor	(from gviewf)
	surface albedo			(from data, or salbedo)
	reflectance of the substrate	(data)
</PRE><P>
The first 6 (0-5) bands of the input image are output from other IPW
commands.  The spectral region, date, time, and location of the
calculation is controlled by gsunlight, gelevrad, and gshade, and are
inherent in the cos solar zenith, beam and diffuse irradiance, and cos
local illumination angle.
</P><P>
Band 6, surface albedo, is used only when the <B>-n</b> parameter is set.
It can be estimated as an average over the grid, derived from a
satellite image, or, for snow, calculated using the program salbedo,
which accounts for angular effects on snow-surface reflectance.
</P><P>
Band 7, reflectance of the substrate, is used for reflection from
adjacent terrain, and should not include angular effects.  It can be
estimated seperately from surface albedo (band 6), or be the same
as surface albedo.
</P>
<H2>OPTIONS</H2>


<DL>
<DT><B>-n</B> 
<DD>
flag for net radiation
</DD>

<P>
<DT><B>-b</B> <I>#bits</I>
<DD>
# bits in output image (default: max of input)
</DD>
</DL>

<H2>OPERANDS</H2>

<DL>
<DT>[<I>image</I>]</DT>

<DD>	image	input image
</DD><P>
</P>
</DL>

<H2>EXAMPLES</H2>

<P>
To calculate topographic distribution of net solar radiation: 
</P><PRE>
	gtoporad -n input_image
</PRE>
<H2>FILES</H2>

<PRE>
     None
</PRE>

<H2>DIAGNOSTICS</H2>

<DL>

<P>
<DT>None
</DT>
</DL>

<H2>RESTRICTIONS</H2>

<P>
None
</P>
<H2>HISTORY</H2>


<DL>
<DT>Aug 1990</DT>
<DD>
	Written by Kelly Longley, Oregon State University,
Environmental Research Laboratory, Corvallis OR
(modified version of IPW toporad program written by
J. Dozier, UCSB)
</DD>
</DL>

<DL>
<DT>May 1991</DT>
<DD>
	Added R0 (mean albedo) as input image band, by
K. Longley, OSU, EPA ERL-C
</DD>
</DL>

<H2>BUGS</H2>

<P>
None that we know of
</P>
<H2>SEE ALSO</H2>


<DL>
<DT>IPW</DT>
<DD>	<B><A href="elevrad.html">elevrad</A></B>,
<B><A href="gelevrad.html">gelevrad</A></B>,
<B><A href="gshade.html">gshade</A></B>,
<B><A href="gsunlight.html">gsunlight</A></B>,
<B><A href="gviewf.html">gviewf</A></B>,
<B><A href="salbedo.html">salbedo</A></B>,
<B><A href="shade.html">shade</A></B>,
	<B><A href="sunlight.html">sunlight</A></B>,
<B><A href="viewf.html">viewf</A></B>
</DD>
</DL>
<P>Dozier, J., 1980.  &quot;A clear-sky spectral solar radiation model for
	snow-covered mountainous terrain&quot;.  Water Resources Research,
	vol. 16, pp. 709-718.
</P>
<P>Dozier, J., and J. Frew, 1981.  &quot;Atmospheric corrections to satellite
	radiometric data over rugged terrain&quot;.  Remote Sensing of
	Environment, vol. 11, pp. 191-205.
</P>
<P>Dozier, J., J. Bruno, and P. Downey, &quot;A faster solution to the
	horizon problem&quot;, Computers and Geosciences, volume 7,
	number 2, pp. 145-151, 1981.
</P>
<P>Dozier, J., and J. Frew, 1990.  Rapid calculation of terrain parameters
	for radiation modeling from digital elevation data&quot;. IEEE
	Transactions on Geoscience and Remote Sensing, vol. 28, no. 5,
	pp. 963-969.
</P>
<P>Dubayah, R., J. Dozier, and F. Davis, 1990.  &quot;Topographic distribution
	of clear-sky radiation over the Konza Prairie, Kansas&quot;.  Water
	Resources Research, vol. 26, no. 4, pp. 679-691.
</P>
<P>Marks, D., R. Dubayah, and K. Longley, 1991.  &quot;Modeling the topographic
	and spectral variability of clear-sky solar radiation at regional
	to continental scales.  Proceedings 1991 IGARSS Symposium,
	Remote Sensing:  Global Monitoring for Earth Management, Espoo,
	Finland, Vol. 3, pp. 1711.
</P>
<P>Dubayah, R., and V. Van Katwijk, 1992.  &quot;The topographic distribution
	of annual incoming solar radiation in the Rio Grande basin&quot;.
	Geophysical Research Letters, vol. 19, pp. 2231-2234.
</P>
<P>Dubayah, R., 1994.  &quot;Modeling a solar radiation topoclimatology for the
	Rio Grande River Basin&quot;.  Journal of Vegetation Science, vol. 5,
	pp. 627-640.
</P>

