<H2>NAME</H2>

<P><B>%name</B> - %description</P>


<H2>SYNOPSIS</H2>

<PRE>
#include "ipw.h"

addr_t allocnd(int elsize, int ndim, ...)

</PRE>

<H2>DESCRIPTION</H2>

<P>
Allocnd dynamically allocates an ndim-dimensional array, where
sizeof(each element) is elsize.  The particular dimensions are given
by the dim1, ..., dimn arguments.  The resulting address should be
cast into a pointer to the proper type of object.
</P><P>
The dynamically allocated array is indexed via dope vectors (i.e., all
but the rightmost dimension are implemented by arrays of pointers).
</P><P>
All space allocated by <B>%name</B> is initialized to 0.
</P><P>
This routine depends on the sizeof operator including all padding to
the correct boundary, and since ecalloc() ensures that the pointer
returned falls on a correct boundary, everything should work out.
The one possible problem that I could think of was if character
pointers are not the same as other types of pointers (true on some
machines).  If this is the case, you're on your own.  Let me know
how you fixed this to work in the general case on your machine.
</P><P>
Because of the extra space required for the dope vectors, arrays
allocated by <B>%name</B>() will consume more memory than
equivalently-dimensioned arrays allocated statically.
</P><P>
The code for <B>%name</B>() has been copied, with minor modifications, from
the function dope(), which was posted to USENET with the following
copyright notice:
</P><PRE>
	(c) Copyright 1985 by Jeff Lee and Georgia Institute of
	Technology
</PRE><PRE>
	Explicit permission is given to use, distribute, copy, and do
	strange things with a fork to this software, but you may not
	sell it because Georgia Tech's name is on it and I believe in
	free software.
</PRE><PRE>
	Jeff Lee
	School of ICS, Georgia Institute of Technology, Atlanta
	gatech!jeff
</PRE>
<H2>RETURN VALUE</H2>

<P>
A pointer to the array is returned, or NULL in case of error.
</P>
<H2>EXAMPLES</H2>

<P>
Use <B>%name</B>() as a general-purpose multidimensional array allocator.
For example:
</P><PRE>
	double	a[3][4];
	double	**b;
</PRE><PRE>
	b = (double **)allocnd(sizeof(double), 2, 3, 4);
</PRE><P>
References of the form b[i][j] will behave equivalently to a[i][j].
</P>
<H2>GLOBALS ACCESSED</H2>

<P>
None.
</P>

<H2>DIAGNOSTICS</H2>

<DL>

<P>
<DT>size overflow during allocation
</DT>
</DL>

<H2>RESTRICTIONS</H2>

<P>
None.
</P>

<H2>HISTORY</H2>



<H2>BUGS</H2>


<H2>SEE ALSO</H2>



